==> ldap-account-manager_8.0.1.orig.tar.bz2: ldap-account-manager-8.0.1/templates/lib/extra/ckeditor/plugins/link/lang/cy.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'cy', {
	acccessKey: 'Allwedd Mynediad',
	advanced: 'Uwch',
	advisoryContentType: 'Math y Cynnwys Cynghorol',
	advisoryTitle: 'Teitl Cynghorol',
	anchor: {
		toolbar: 'Angor',
		menu: 'Golygu\'r Angor',
		title: 'Priodweddau\'r Angor',
		name: 'Enw\'r Angor',
		errorName: 'Teipiwch enw\'r angor',
		remove: 'Tynnwch yr Angor'
	},
	anchorId: 'Gan Id yr Elfen',
	anchorName: 'Gan Enw\'r Angor',
	charset: 'Set Nodau\'r Adnodd Cysylltiedig',
	cssClasses: 'Dosbarthiadau Dalen Arddull',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Cyfeiriad E-Bost',
	emailBody: 'Corff y Neges',
	emailSubject: 'Testun y Neges',
	id: 'Id',
	info: 'Gwyb y Ddolen',
	langCode: 'Cod Iaith',
	langDir: 'Cyfeiriad Iaith',
	langDirLTR: 'Chwith i\'r Dde (LTR)',
	langDirRTL: 'Dde i\'r Chwith (RTL)',
	menu: 'Golygu Dolen',
	name: 'Enw',
	noAnchors: '(Dim angorau ar gael yn y ddogfen)',
	noEmail: 'Teipiwch gyfeiriad yr e-bost',
	noUrl: 'Teipiwch URL y ddolen',
	noTel: 'Please type the phone number', // MISSING
	other: '<eraill>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dibynnol (Netscape)',
	popupFeatures: 'Nodweddion Ffenestr Bop',
	popupFullScreen: 'Sgrin Llawn (IE)',
	popupLeft: 'Safle Chwith',
	popupLocationBar: 'Bar Safle',
	popupMenuBar: 'Dewislen',
	popupResizable: 'Ailfeintiol',
	popupScrollBars: 'Barrau Sgrolio',
	popupStatusBar: 'Bar Statws',
	popupToolbar: 'Bar Offer',
	popupTop: 'Safle Top',
	rel: 'Perthynas',
	selectAnchor: 'Dewiswch Angor',
	styles: 'Arddull',
	tabIndex: 'Indecs Tab',
	target: 'Targed',
	targetFrame: '<ffrâm>',
	targetFrameName: 'Enw Ffrâm y Targed',
	targetPopup: '<ffenestr bop>',
	targetPopupName: 'Enw Ffenestr Bop',
	title: 'Dolen',
	toAnchor: 'Dolen at angor yn y testun',
	toEmail: 'E-bost',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Dolen',
	type: 'Math y Ddolen',
	unlink: 'Datgysylltu',
	upload: 'Lanlwytho'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/cy.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'cy', {
	acccessKey: 'Allwedd Mynediad',
	advanced: 'Uwch',
	advisoryContentType: 'Math y Cynnwys Cynghorol',
	advisoryTitle: 'Teitl Cynghorol',
	anchor: {
		toolbar: 'Angor',
		menu: 'Golygu\'r Angor',
		title: 'Priodweddau\'r Angor',
		name: 'Enw\'r Angor',
		errorName: 'Teipiwch enw\'r angor',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Tynnwch yr Angor'
	},
	anchorId: 'Gan Id yr Elfen',
	anchorName: 'Gan Enw\'r Angor',
	charset: 'Set Nodau\'r Adnodd Cysylltiedig',
	cssClasses: 'Dosbarthiadau Dalen Arddull',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Cyfeiriad E-Bost',
	emailBody: 'Corff y Neges',
	emailSubject: 'Testun y Neges',
	id: 'Id',
	info: 'Gwyb y Ddolen',
	langCode: 'Cod Iaith',
	langDir: 'Cyfeiriad Iaith',
	langDirLTR: 'Chwith i\'r Dde (LTR)',
	langDirRTL: 'Dde i\'r Chwith (RTL)',
	menu: 'Golygu Dolen',
	name: 'Enw',
	noAnchors: '(Dim angorau ar gael yn y ddogfen)',
	noEmail: 'Teipiwch gyfeiriad yr e-bost',
	noUrl: 'Teipiwch URL y ddolen',
	noTel: 'Please type the phone number', // MISSING
	other: '<eraill>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dibynnol (Netscape)',
	popupFeatures: 'Nodweddion Ffenestr Bop',
	popupFullScreen: 'Sgrin Llawn (IE)',
	popupLeft: 'Safle Chwith',
	popupLocationBar: 'Bar Safle',
	popupMenuBar: 'Dewislen',
	popupResizable: 'Ailfeintiol',
	popupScrollBars: 'Barrau Sgrolio',
	popupStatusBar: 'Bar Statws',
	popupToolbar: 'Bar Offer',
	popupTop: 'Safle Top',
	rel: 'Perthynas',
	selectAnchor: 'Dewiswch Angor',
	styles: 'Arddull',
	tabIndex: 'Indecs Tab',
	target: 'Targed',
	targetFrame: '<ffrâm>',
	targetFrameName: 'Enw Ffrâm y Targed',
	targetPopup: '<ffenestr bop>',
	targetPopupName: 'Enw Ffenestr Bop',
	title: 'Dolen',
	toAnchor: 'Dolen at angor yn y testun',
	toEmail: 'E-bost',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Dolen',
	type: 'Math y Ddolen',
	unlink: 'Datgysylltu',
	upload: 'Lanlwytho'
} );
